Index: leahi.pro
===================================================================
diff -u -ref7ded49d368a1002b73819d7d71673519b1ae29 -r4b86351821cd865f5d0383190a17b2137f79f9aa
--- leahi.pro (.../leahi.pro) (revision ef7ded49d368a1002b73819d7d71673519b1ae29)
+++ leahi.pro (.../leahi.pro) (revision 4b86351821cd865f5d0383190a17b2137f79f9aa)
@@ -152,6 +152,7 @@
\ # Controllers
sources/ApplicationController.h \
sources/device/DeviceController.h \
+ sources/model/confirm/MDuetConfirmTDi.h \
sources/model/dd/adjustment/settings/MAdjustDDSerialNumberResponse.h \
sources/model/dd/adjustment/settings/MAdjustDDVersionsResponse.h \
sources/model/dd/data/MDDBloodLeakData.h \
@@ -334,7 +335,6 @@
sources/model/td/adjustment/posttreatment/MPostTreatmentAdjustDisposablesRemovalConfirmResponse.h \
sources/model/td/adjustment/posttreatment/MPostTreatmentAdjustPatientDisconnectionConfirmResponse.h \
\ # ---------- Models - confirm
- sources/model/confirm/MDuetConfirmHDi.h \
\ # ---------- Models - POST
sources/model/dg/data/post/MDGPostFinalResultData.h \
sources/model/dg/data/post/MDGPostSingleResultData.h \
@@ -360,7 +360,6 @@
sources/model/hd/data/posttreatment/MPostTreatmentStatesData.h \
\ # ---------- Models - HD - Adjustment
sources/model/hd/adjustment/MAdjustRequestsBase.h \
- sources/model/hd/adjustment/MAdjustPowerOff.h \
sources/model/hd/adjustment/settings/MAdjustHDRequests.h \
\ # ---------- Models - HD - Adjustment - Settings
sources/model/hd/adjustment/settings/MAdjustHDAlarmVolumeResponse.h \
@@ -522,6 +521,7 @@
\ # Controllers
sources/ApplicationController.cpp \
sources/device/DeviceController.cpp \
+ sources/model/confirm/MDuetConfirmTDi.cpp \
sources/model/dd/adjustment/settings/MAdjustDDSerialNumberResponse.cpp \
sources/model/dd/adjustment/settings/MAdjustDDVersionsResponse.cpp \
sources/model/dd/data/MDDBloodLeakData.cpp \
@@ -609,6 +609,8 @@
sources/model/td/data/treatmentlog/MTreatmentLogAlarmData.cpp \
sources/model/td/data/treatmentlog/MTreatmentLogEventData.cpp \
sources/model/td/data/treatmentlog/MTreatmentLogAvrgeData.cpp \
+ \ # ---------- Models - TD - Adjustment
+ sources/model/td/adjustment/MAdjustPowerOff.h \
\ # ---------- Models - TD - Adjustment - In-Treatment
sources/model/td/adjustment/treatment/MTreatmentAdjustBloodPrimeResponse.cpp \
sources/model/td/adjustment/treatment/MTreatmentAdjustBloodFlowRateResponse.cpp \
@@ -631,7 +633,6 @@
sources/model/td/adjustment/treatment/MTreatmentAdjustVitalsResponse.cpp \
sources/model/td/adjustment/treatment/MTreatmentAdjustRinsebackResponse.cpp \
\ # ---------- Models - CONFIRM
- sources/model/confirm/MDuetConfirmHDi.cpp \
\ # ---------- Models - POST
sources/model/dg/data/post/MDGPostFinalResultData.cpp \
sources/model/dg/data/post/MDGPostSingleResultData.cpp \
@@ -654,6 +655,8 @@
\ # ---------- Models - Data - States
sources/model/hd/data/pretreatment/MPreTreatmentStatesData.cpp \
sources/model/hd/data/posttreatment/MPostTreatmentStatesData.cpp \
+ \ # ---------- Models - TD - Adjustment
+ sources/model/td/adjustment/MAdjustPowerOff.cpp \
\ # ---------- Models - TD - Adjustment - Settings
sources/model/td/adjustment/settings/MAdjustTDDateTimeResponse.cpp \
sources/model/td/adjustment/settings/MTDInstitutionalRecordResponse.cpp \
@@ -670,8 +673,6 @@
sources/model/td/adjustment/treatment/MTreatmentAdjustRecirculateResponse.cpp \
\ # ---------- Models - DD - Adjustment - Settings
sources/model/dd/adjustment/settings/MAdjustDDDateTimeResponse.cpp \
- \ # ---------- Models - HD - Adjustment
- sources/model/hd/adjustment/MAdjustPowerOff.cpp \
\ # ---------- Models - HD - Adjustment - Settings
sources/model/hd/adjustment/settings/MAdjustHDAlarmVolumeResponse.cpp \
\ # ---------- Models - HD - Adjustment - Pre-Treatment
Index: leahi.qrc
===================================================================
diff -u -rdc8969f6c7bbdb46d2de22622e58e457ceb37df4 -r4b86351821cd865f5d0383190a17b2137f79f9aa
--- leahi.qrc (.../leahi.qrc) (revision dc8969f6c7bbdb46d2de22622e58e457ceb37df4)
+++ leahi.qrc (.../leahi.qrc) (revision 4b86351821cd865f5d0383190a17b2137f79f9aa)
@@ -44,6 +44,7 @@
sources/gui/qml/dialogs/HeparinRxAdjustment.qml
sources/gui/qml/dialogs/AlarmDialog.qml
sources/gui/qml/dialogs/PatientIdEntry.qml
+ sources/gui/qml/dialogs/DryDemoDialog.qml
sources/gui/qml/dialogs/diagnostics/DiagnosticsDialog.qml
Index: sources/gui/qml/pages/pretreatment/create/PreTreatmentCreatePatientPrescription.qml
===================================================================
diff -u -r1eedad37ea1cad5c9aa41ac082614d082f525a7f -r4b86351821cd865f5d0383190a17b2137f79f9aa
--- sources/gui/qml/pages/pretreatment/create/PreTreatmentCreatePatientPrescription.qml (.../PreTreatmentCreatePatientPrescription.qml) (revision 1eedad37ea1cad5c9aa41ac082614d082f525a7f)
+++ sources/gui/qml/pages/pretreatment/create/PreTreatmentCreatePatientPrescription.qml (.../PreTreatmentCreatePatientPrescription.qml) (revision 4b86351821cd865f5d0383190a17b2137f79f9aa)
@@ -41,6 +41,29 @@
_heparinRx.reset()
vTreatmentCreate.ufPreWeight = vTreatmentRanges.weightDef
vTreatmentCreate.ufEstimatedTargetWeight = vTreatmentRanges.weightDef
+
+ if ( _GuiView.dryDemoMode ) {
+ vTreatmentCreate.hdfTreatmentModeSet = true
+ vTreatmentCreate.substitutionFluidVolumeSet = true
+ vTreatmentCreate.bloodFlowRateSet = true
+ vTreatmentCreate.dialysateFlowRateSet = true
+ vTreatmentCreate.treatmentDurationSet = true
+ vTreatmentCreate.ultrafiltrationVolumeSet = true
+ vTreatmentCreate.acidConcentrateSet = true
+ vTreatmentCreate.dryBicarbCartSizeSet = true
+ vTreatmentCreate.dialyzerTypeSet = true
+ vTreatmentCreate.dialysateTempSet = true
+ vTreatmentCreate.heparinBolusVolumeSet = true
+ vTreatmentCreate.heparinDispensingRateSet = true
+ vTreatmentCreate.heparinDeliveryDurationSet = true
+
+ vTreatmentCreate.substitutionFluidVolume = vTreatmentRanges.substitutionVolumeDef
+ vTreatmentCreate.bloodFlowRate = vTreatmentRanges.bloodFlowRateDef
+ vTreatmentCreate.dialysateFlowRate = vTreatmentRanges.dialysateFlowRateDef
+ vTreatmentCreate.treatmentDuration = vTreatmentRanges.treatmentDurationDef
+ vTreatmentCreate.ultrafiltrationVolume = vTreatmentRanges.ultrafiltrationVolumeDef
+ vTreatmentCreate.dialysateTemp = vTreatmentRanges.dialysateTempDef
+ }
}
function refreshAll () {
Index: sources/canbus/MessageGlobals.h
===================================================================
diff -u -rdc8969f6c7bbdb46d2de22622e58e457ceb37df4 -r4b86351821cd865f5d0383190a17b2137f79f9aa
--- sources/canbus/MessageGlobals.h (.../MessageGlobals.h) (revision dc8969f6c7bbdb46d2de22622e58e457ceb37df4)
+++ sources/canbus/MessageGlobals.h (.../MessageGlobals.h) (revision 4b86351821cd865f5d0383190a17b2137f79f9aa)
@@ -49,12 +49,12 @@
// but if the model still needs more the model will fail.
// so it is better to keep them next to each other to make sure they are in sync.
// ----
- {Gui::GuiActionType::ID_PowerOff , 1 }, // 1 byte
+ {Gui::GuiActionType::ID_PowerOff , 1 }, // 1 parameters each 4bytes
{Gui::GuiActionType::ID_ShuttingDown , 0 },
{Gui::GuiActionType::ID_TDCheckIn , 0 }, //// ----- @LEAHIZED
// Generic Confirm
- {Gui::GuiActionType::ID_DuetConfirmHDi , 3 * 4 }, // 3 parameters each 4bytes
+ {Gui::GuiActionType::ID_DuetConfirmTDi , 3 * 4 }, // 3 parameters each 4bytes
{Gui::GuiActionType::ID_DuetConfirmUIr , 2 * 4 }, // 2 parameters each 4bytes
// POST
@@ -86,8 +86,8 @@
{Gui::GuiActionType::ID_BloodPrime , 4 * 4 }, // 4 parameters each 4bytes
{Gui::GuiActionType::ID_TreatmentStop , 2 * 4 }, // 2 parameters each 4bytes
{Gui::GuiActionType::ID_TDAirBubbleData , 2 * 4 }, // 2 parameters each 4bytes
- {Gui::GuiActionType::ID_TDAirPumpData , 2 * 4 }, // 2 parameters each 4bytes
- {Gui::GuiActionType::ID_TDAirTrapData , 6 * 4 }, // 6 parameters each 4bytes
+ {Gui::GuiActionType::ID_TDAirPumpData , 5 * 4 }, // 5 parameters each 4bytes
+ {Gui::GuiActionType::ID_TDAirTrapData , 10 * 4 }, // 10 parameters each 4bytes
{Gui::GuiActionType::ID_HDBloodLeakData , 4 * 4 }, // 4 parameters each 4bytes
// ----
{Gui::GuiActionType::ID_TDOpModeData , 2 * 4 }, // 2 parameter each 4bytes
@@ -103,15 +103,15 @@
{Gui::GuiActionType::ID_DGAccelerometerData , 9 * 4 }, // 9 parameters each 4bytes
//DD Data Messages
{Gui::GuiActionType::ID_DDValvesStatesData , 4 * 1 + 28 }, // 1 parameter 32bits & 28 parameters each 1 byte
- {Gui::GuiActionType::ID_DDPressuresData , 14 * 4 }, // 14 parameters each 4bytes
+ {Gui::GuiActionType::ID_DDPressuresData , 6 * 4 }, // 6 parameters each 4bytes
{Gui::GuiActionType::ID_DDConductivityData , 5 * 4 }, // 5 parameters each 4bytes
{Gui::GuiActionType::ID_DDConcentratePumpData , 25 * 4 }, // 25 parameters each 4bytes
- {Gui::GuiActionType::ID_DDTemperaturesData , 15 * 4 }, // 15 parameters each 4bytes
+ {Gui::GuiActionType::ID_DDTemperaturesData , 23 * 4 }, // 23 parameters each 4bytes
{Gui::GuiActionType::ID_DDDialysatePumpData , 20 * 4 }, // 20 parameters each 4bytes
{Gui::GuiActionType::ID_DDHeatersData , 8 * 4 }, // 8 parameters each 4bytes // NOTE: may contain optional 9 parameters each 4bytes
- {Gui::GuiActionType::ID_DDLevelData , 3 * 4 }, // 3 parameters each 4bytes
+ {Gui::GuiActionType::ID_DDLevelData , 5 * 4 }, // 5 parameters each 4bytes
{Gui::GuiActionType::ID_DDGenDialysateData , 4 * 4 }, // 4 parameters each 4bytes
- {Gui::GuiActionType::ID_DDBloodLeakData , 1 * 4 }, // 1 parameters each 4bytes
+ {Gui::GuiActionType::ID_DDBloodLeakData , 10 * 4 }, // 10 parameters each 4bytes
{Gui::GuiActionType::ID_DDOperationModeData , 2 * 4 }, // 2 parameter each 4bytes
//FP Data Messages
@@ -129,11 +129,11 @@
{Gui::GuiActionType::ID_HDUsageInfoReq , 0 * 4 }, // 0 parameters each 4bytes
{Gui::GuiActionType::ID_HDUsageInfoRsp , 4 * 4 + 2 }, // 4 parameters each 4bytes + 1 parameter 2 bytes
//TD Data Messages
- {Gui::GuiActionType::ID_TDVoltageData , 11 * 4 }, //11 parameters each 4bytes
- {Gui::GuiActionType::ID_TDValvesData , 3 * 4 + 2*2 }, // 5 parameters each 4bytes + 2 parametres 2 bytes
- {Gui::GuiActionType::ID_TDEjectorData , 2 * 4 }, // 2 parameters each 4bytes
+ {Gui::GuiActionType::ID_TDVoltageData , 8 * 4 }, // 8 parameters each 4bytes
+ {Gui::GuiActionType::ID_TDValvesData , 3 * 4 + 7*2 }, // 5 parameters each 4bytes + 2 parametres 2 bytes
+ {Gui::GuiActionType::ID_TDEjectorData , 4 * 4 }, // 4 parameters each 4bytes
{Gui::GuiActionType::ID_TDSwitchesData , 1 * 4 }, // 3 parameters each 4bytes
- {Gui::GuiActionType::ID_TDBatteryData , 2 * 4 }, // 2 parameters each 4bytes //// TODO: The payload is TBD (as indicated by the provided screen items)
+ {Gui::GuiActionType::ID_TDBatteryData , 2 * 4 }, // 2 parameters each 4bytes
{Gui::GuiActionType::ID_TDTemperatureData , 1 * 4 }, // 1 parameters each 4bytes //// TODO: The payload is TBD (as indicated by the provided screen items)
{Gui::GuiActionType::ID_TreatmentParametersSetPointData , 3 * 4 }, // 3 parameters each 4bytes